@@ -1,16 +1,19 @@
 #'Converts RLum.Analysis-objects and RLum.Data.Curve-objects to RLum2Risoe.BINfileData-objects
 #'
 #'The functions converts [RLum.Analysis-class] and [RLum.Data.Curve-class] objects and a [list] of those
-#'to [Risoe.BINfileData-class] objects. The funtion intends to provide a minimum of compatiblility
+#'to [Risoe.BINfileData-class] objects. The function intends to provide a minimum of compatibility
 #'between both formats. The created [RLum.Analysis-class] object can be later exported to a
 #'BIN-file using the function [write_R2BIN].
 #'
 #'@param object [RLum.Analysis-class] or [RLum.Data.Curve-class] (**required**): input object to
 #'be converted
 #'
-#'@section Function version: 0.1.0
+#'@param keep.position.number [logical] (with default): keeps the original position number or re-calculate
+#'the numbers to avoid doubling
 #'
-#'@author  Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#'@section Function version: 0.1.3
+#'
+#'@author  Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #'@seealso [RLum.Analysis-class], [RLum.Data.Curve-class], [write_R2BIN]
 #'
@@ -30,7 +33,8 @@
 #'@md
 #'@export
 convert_RLum2Risoe.BINfileData <- function(
-  object
+  object,
+  keep.position.number = FALSE
 
 ){
 
@@ -48,7 +52,7 @@ convert_RLum2Risoe.BINfileData <- function(
       return(object_list[[1]])
 
     }else{
-      return(merge_Risoe.BINfileData(object_list))
+      return(merge_Risoe.BINfileData(object_list, keep.position.number = keep.position.number))
 
     }
 
@@ -78,7 +82,6 @@ convert_RLum2Risoe.BINfileData <- function(
   ##write DATA
   prototype@DATA <- lapply(records, function(x) {x@data[,2]})
 
-
   # Create METADATA -----------------------------------------------------------------------------
 
   ##create METADATA list
@@ -259,7 +262,7 @@ convert_RLum2Risoe.BINfileData <- function(
     ##(a) create LTYPE from names of objects
     LTYPE <- vapply(names(object), function(s){
       if(grepl(pattern = " (", x = s, fixed = TRUE)){
-        strsplit(names(object), split = " (", fixed = TRUE)[[1]][1]
+        strsplit(s, split = " (", fixed = TRUE)[[1]][1]
 
       }else{
         s
@@ -268,7 +271,6 @@ convert_RLum2Risoe.BINfileData <- function(
 
     }, FUN.VALUE = character(1))
 
-
     ##(b) replace characters
     ##(b.1) irradiation
     LTYPE <-  gsub(pattern = "irradiation", replacement = "USER", fixed = TRUE, x = LTYPE)
